annotations
library
Classes
-
BelongsToRelation<T>
-
Annotation to define a BelongsTo relationship.
-
DatumField
-
Annotation to specify a custom name for a field in the Datum map.
-
DatumIgnore
-
Annotation for fields that should be excluded from Datum serialization or metadata methods.
-
DatumJsonUtils
-
Utilities for JSON encoding/decoding to support generated code.
-
DatumSerializable
-
Annotation for classes that should have Datum code generated.
-
HasManyRelation<T>
-
Annotation to define a HasMany relationship.
-
HasOneRelation<T>
-
Annotation to define a HasOne relationship.
-
ManyToManyRelation<T, P>
-
Annotation to define a ManyToMany relationship.