DatumSerializable class
Annotation for classes that should have Datum code generated.
- Annotations
-
- @Target.new({TargetKind.classType})
Constructors
- DatumSerializable({String? tableName, bool generateMixin = false})
-
const
Properties
- generateMixin → bool
-
Whether to generate a mixin with all required method implementations.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- tableName → String?
-
The table name for this entity. If not provided, the class name will be used (converted to snake_case).
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited